@@ -248,6 +248,7 @@ impl FlatpakManifest {
         }
         return self.id.to_string();
     }
+
     pub fn load_from_file(path: String) -> Result<FlatpakManifest, String> {
         let file_path = path::Path::new(&path);
         if !file_path.is_file() {
@@ -392,6 +393,7 @@ impl FlatpakManifest {
         }
         return max_depth;
     }
+
     pub fn is_extension(&self) -> bool {
         if let Some(e) = self.build_extension {
             return e;
@@ -439,14 +441,21 @@ impl FlatpakModule {
     }
 }
 
+pub const AUTOTOOLS: &str = "autotools";
+pub const CMAKE: &str = "cmake";
+pub const CMAKE_NINJA: &str = "cmake-ninja";
+pub const MESON: &str = "meson";
+pub const QMAKE: &str = "qmake";
+pub const SIMPLE: &str = "simple";
+
 lazy_static! {
-    static ref FLATPAK_BUILD_SYSTEMS: Vec<String> = vec![
-        "autotools".to_string(),
-        "cmake".to_string(),
-        "cmake-ninja".to_string(),
-        "meson".to_string(),
-        "simple".to_string(),
-        "qmake".to_string(),
+    pub static ref FLATPAK_BUILD_SYSTEMS: Vec<String> = vec![
+        AUTOTOOLS.to_string(),
+        CMAKE.to_string(),
+        CMAKE_NINJA.to_string(),
+        MESON.to_string(),
+        QMAKE.to_string(),
+        SIMPLE.to_string(),
     ];
 }
 
@@ -619,6 +628,7 @@ impl FlatpakModuleDescription {
         }
         all_urls
     }
+
     pub fn get_buildsystem(&self) -> Option<String> {
         if !self.buildsystem.is_empty() {
             return Some(self.buildsystem.to_string());
@@ -628,6 +638,7 @@ impl FlatpakModuleDescription {
         }
         return None;
     }
+
     pub fn is_patched(&self) -> bool {
         for source in &self.sources {
             if let FlatpakSource::Description(sd) = source {
@@ -831,7 +842,7 @@ impl FlatpakModuleDescription {
 }
 
 lazy_static! {
-    static ref SOURCE_TYPES: Vec<String> = vec![
+    pub static ref SOURCE_TYPES: Vec<String> = vec![
         "archive".to_string(),
         "git".to_string(),
         "bzr".to_string(),
@@ -884,6 +895,7 @@ impl FlatpakSource {
             None => None,
         }
     }
+
     pub fn get_all_mirror_urls(&self) -> Vec<String> {
         let mut response: Vec<String> = vec![];
 
@@ -915,6 +927,7 @@ impl FlatpakSource {
         }
         return response;
     }
+
     pub fn get_type_name(&self) -> String {
         return match self {
             FlatpakSource::Path(_) => "path".to_string(),
@@ -926,24 +939,28 @@ impl FlatpakSource {
             }
         };
     }
+
     pub fn has_commit(&self) -> bool {
         return match self {
             FlatpakSource::Path(_) => false,
             FlatpakSource::Description(d) => d.commit.is_some(),
         };
     }
+
     pub fn has_tag(&self) -> bool {
         return match self {
             FlatpakSource::Path(_) => false,
             FlatpakSource::Description(d) => d.tag.is_some(),
         };
     }
+
     pub fn has_branch(&self) -> bool {
         return match self {
             FlatpakSource::Path(_) => false,
             FlatpakSource::Description(d) => d.branch.is_some(),
         };
     }
+
     pub fn type_is_valid(&self) -> bool {
         return match self {
             FlatpakSource::Path(_) => true,
@@ -955,12 +972,14 @@ impl FlatpakSource {
             }
         };
     }
+
     pub fn type_is_empty(&self) -> bool {
         return match self {
             FlatpakSource::Path(_) => false,
             FlatpakSource::Description(d) => d.r#type.is_none(),
         };
     }
+
     pub fn supports_mirror_urls(&self) -> bool {
         let type_name = self.get_type_name();
         // FIXME why are mirror urls not supported for types git, svn and bzr.
